@@ -126,7 +126,7 @@ use Data::Dumper;
 
 use vars qw($VERSION);
 
-$VERSION = '3.18';
+$VERSION = '3.20';
 
 use constant {
     DIRECTORY    => 0,
@@ -169,7 +169,7 @@ there, it opens it, otherwise it creates a new one.
 =cut
 
 sub open_store {
-    my $opts = ref $_[$#_] ? pop : {};
+    my $opts = ref( $_[$#_] ) ? pop : {};
     my $directory = pop @_;
     my $pkg = shift @_ || 'Data::RecordStore';
 
@@ -179,14 +179,9 @@ sub open_store {
     #   root/RECYC_SILO        <-- recycle silo directory
     #   root/silos/            <-- directory for silo directories
 
-    my $pathopts = { error => \my $err };
-    if( $opts->{group} ) {
-        $pathopts->{group} = $opts->{group};
-    }
-    make_path( "$directory/silos", $pathopts );
+    make_path( "$directory/silos", { error => \my $err, map { $_ => $opts->{$_} } grep { $opts->{$_} } qw( group mode ) } );
     if( @$err ) {
-        my( $err ) = values %{ $err->[0] };
-        die $err;
+        die join ',',map { values %$_ } @$err;
     }
     my $record_index_directory = "$directory/RECORD_INDEX_SILO";
 
@@ -198,6 +193,7 @@ sub open_store {
     my $FH;
     if( -e $version_file ) {
         CORE::open $FH, "<", $version_file;
+        $opts->{group} && chown -1, $opts->{group}, $FH;
         $version = <$FH>;
         chomp $version;
 
@@ -216,6 +212,7 @@ sub open_store {
         }
         $version = $VERSION;
         CORE::open $FH, ">", $version_file;
+        $opts->{group} && chown -1, $opts->{group}, $FH;
         print $FH "$version\n";
     }
     close $FH;
@@ -554,7 +551,7 @@ sub _get_silo {
     my $silo_row_size = int( exp $silo_index );
 
     # storing first the size of the record, uuencode flag, then the bytes of the record
-    my $silo = Data::RecordStore::Silo->open_silo( "LIZ*", "$self->[DIRECTORY]/silos/${silo_index}_RECSTORE", $silo_row_size, $silo_index, $self->[OPTIONS] );
+    my $silo = Data::RecordStore::Silo->open_silo( "LIZ*", "$self->[DIRECTORY]/silos/${silo_index}_RECSTORE", $silo_row_size, $self->[OPTIONS] );
 
     $self->[SILOS][ $silo_index ] = $silo;
     $silo;
@@ -621,7 +618,7 @@ use constant {
     FILE_SIZE        => 2,
     FILE_MAX_RECORDS => 3,
     TMPL             => 4,
-    LOCK             => 5,
+    OPTIONS          => 5,
 };
 
 $Data::RecordStore::Silo::MAX_SIZE = 2_000_000_000;
@@ -664,20 +661,15 @@ sub open_silo {
         $file_max_records = 1;
     }
     my $file_max_size = $file_max_records * $record_size;
-    my $lock_fh;
     unless( -d $directory ) {
         die "Data::RecordStore::Silo->open_silo Error opening record store. $directory exists and is not a directory" if -e $directory;
-        my $path_opts = {};
-        if( $path_opts->{group} ) {
-            $path_opts->{group} = $opts->{group};
-        }
-        make_path( $directory, $path_opts ) or die "Data::RecordStore::Silo->open_silo : Unable to create directory $directory";
+        make_path( $directory, { map { $_ => $opts->{$_} } grep { $opts->{$_} } qw( group mode ) } ) or die "Data::RecordStore::Silo->open_silo : Unable to create directory $directory";
     }
     unless( -e "$directory/0" ){
         CORE::open( my $fh, ">", "$directory/0" ) or die "Data::RecordStore::Silo->open_silo : Unable to open '$directory/0' : $!";
+        $opts->{group} && chown -1, $opts->{group}, $fh;
         close $fh;
     }
-    CORE::open( $lock_fh, ">", "$directory/l" ) or die "Data::RecordStore::Silo->open_silo : Unable to open '$directory/l' : $!";
 
     unless( -w "$directory/0" ){
         die "Data::RecordStore::Silo->open_silo Error operning record store. $directory exists but is not writeable" if -e $directory;
@@ -689,7 +681,7 @@ sub open_silo {
         $file_max_size,
         $file_max_records,
         $template,
-        $lock_fh,
+        $opts,
     ], $class;
 
     $silo;
@@ -908,6 +900,7 @@ sub _ensure_entry_count {
             # fill the last flie up with \0
 
             CORE::open( my $fh, "+<", "$self->[DIRECTORY]/$write_file" ) or die "Data::RecordStore::Silo->ensure_entry_count : unable to open '$self->[DIRECTORY]/$write_file' : $!";
+            $self->[OPTIONS]{group} && chown -1, $self->[OPTIONS]{group}, $fh;
             binmode $fh; # for windows
             my $nulls = "\0" x ( $records_needed_to_fill * $self->[RECORD_SIZE] );
             (my $pos = sysseek( $fh, $self->[RECORD_SIZE] * $existing_file_records, SEEK_SET )) && (my $wrote = syswrite( $fh, $nulls )) || die "Data::RecordStore::Silo->ensure_entry_count : unable to write blank to '$self->[DIRECTORY]/$write_file' : $!";
@@ -920,6 +913,7 @@ sub _ensure_entry_count {
 
             die "Data::RecordStore::Silo->ensure_entry_count : file $self->[DIRECTORY]/$write_file already exists" if -e $write_file;
             CORE::open( my $fh, ">", "$self->[DIRECTORY]/$write_file" ) or die "Data::RecordStore::Silo->ensure_entry_count : unable to create '$self->[DIRECTORY]/$write_file' : $!";
+            $self->[OPTIONS]{group} && chown -1, $self->[OPTIONS]{group}, $fh;
             binmode $fh; # for windows
             my $nulls = "\0" x ( $self->[FILE_MAX_RECORDS] * $self->[RECORD_SIZE] );
             (my $pos = sysseek( $fh, 0, SEEK_SET )) && (my $wrote = syswrite( $fh, $nulls )) || die "Data::RecordStore::Silo->ensure_entry_count : unable to write blank to '$self->[DIRECTORY]/$write_file' : $!";
@@ -932,6 +926,7 @@ sub _ensure_entry_count {
 
             die "Data::RecordStore::Silo->ensure_entry_count : file $self->[DIRECTORY]/$write_file already exists" if -e $write_file;
             CORE::open( my $fh, ">", "$self->[DIRECTORY]/$write_file" ) or die "Data::RecordStore::Silo->ensure_entry_count : unable to create '$self->[DIRECTORY]/$write_file' : $!";
+            $self->[OPTIONS]{group} && chown -1, $self->[OPTIONS]{group}, $fh;
             binmode $fh; # for windows
             my $nulls = "\0" x ( $needed * $self->[RECORD_SIZE] );
             (my $pos = sysseek( $fh, 0, SEEK_SET )) && (my $wrote = syswrite( $fh, $nulls )) || die "Data::RecordStore::Silo->ensure_entry_count : unable to write blank to '$self->[DIRECTORY]/$write_file' : $!";
@@ -966,6 +961,7 @@ sub _fh {
 
     my $file = $files[$f_idx];
     CORE::open( my $fh, "+<", "$self->[DIRECTORY]/$file" ) or die "Data::RecordStore::Silo->_fhu nable to open '$self->[DIRECTORY]/$file' : $! $?";
+    $self->[OPTIONS]{group} && chown -1, $self->[OPTIONS]{group}, $fh;
     binmode $fh; # for windows
 
     (($id - ($f_idx*$self->[FILE_MAX_RECORDS])) - 1,$fh,"$self->[DIRECTORY]/$file",$f_idx);
@@ -1400,6 +1396,6 @@ __END__
        under the same terms as Perl itself.
 
 =head1 VERSION
-       Version 3.18  (April, 2018))
+       Version 3.20  (April, 2018))
 
 =cut
